==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorDescriptionMetadata.a == null) {
                ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
            }
            if (a.k(ToolActionSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("Size", "Number:double");
            a.item("IsGroupHeaderSeparator", "Boolean");
        }
        static d(a) {
            ToolActionSeparatorDescriptionMetadata.b(a);
            a.ad("ToolActionSeparator", () => new ToolActionSeparatorDescription());
            a.ac("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorDescriptionMetadata.$t = markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorDescriptionMetadata.a == null) {
                ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
            }
            if (a.k(ToolActionSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("Size", "Number:double");
            a.item("IsGroupHeaderSeparator", "Boolean");
        }
        static d(a) {
            ToolActionSeparatorDescriptionMetadata.b(a);
            a.ae("ToolActionSeparator", () => new ToolActionSeparatorDescription());
            a.ad("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorDescriptionMetadata.$t = markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
})();
